@@ -4,9 +4,13 @@ use crate::error::Error;
 use crate::subscription::Subscription;
 use crate::topic::Topic;
 use google_auth::TokenManager;
+use once_cell::sync::OnceCell;
 use tonic::transport::{Certificate, Channel, ClientTlsConfig};
 use tonic::{IntoRequest, Request};
 
+static DOMAIN_NAME: OnceCell<String> = OnceCell::new();
+static ENDPOINT: OnceCell<String> = OnceCell::new();
+
 #[derive(Clone)]
 pub struct Client {
     pub(crate) project_id: String,
@@ -16,18 +20,20 @@ pub struct Client {
 }
 
 impl Client {
-    pub(crate) const DOMAIN_NAME: &'static str = "pubsub.googleapis.com";
-    pub(crate) const ENDPOINT: &'static str = "https://pubsub.googleapis.com";
     pub(crate) const SCOPES: [&'static str; 2] = [
         "https://www.googleapis.com/auth/cloud-platform",
         "https://www.googleapis.com/auth/pubsub",
     ];
     pub async fn new(project_id: &str) -> Result<Self, Error> {
+        if let Ok(host) = std::env::var("PUBSUB_EMULATOR_HOST") {
+            DOMAIN_NAME.set(host.clone()).unwrap();
+            ENDPOINT.set(format!("http://{}", host)).unwrap();
+        }
         let pem = get_pem();
         let tls_config = ClientTlsConfig::new()
             .ca_certificate(Certificate::from_pem(&pem))
-            .domain_name(Self::DOMAIN_NAME);
-        let channel = Channel::from_static(Self::ENDPOINT)
+            .domain_name(DOMAIN_NAME.get().unwrap());
+        let channel = Channel::from_static(ENDPOINT.get().unwrap())
             .tls_config(tls_config)?
             .connect()
             .await?;
